# UserResourceAccessInfo

A ResourceAccessInfo describes whether a user has access to a resource. More specific collections may exist to describe a user's access for a specific type of resource, but this one serves to give a high level overview of access for a specific user. 
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**status** | [**UserResourceAccessInfoStatus**](UserResourceAccessInfoStatus.md) |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


